# Contributing

When contributing to this repository, please first discuss the change you wish to make via issue,
email, or any other method with the owners of this repository before making a change. 

Please note we have a code of conduct, please follow it in all your interactions with the project.

## Pull Request Process
   
1. Fork the repo and create your development branch from `master`.
2. If you've added code that should be tested, add tests.
3. If needed please update the documentation, including in-code docstrings.
4. Ensure the test suite passes by summoning a `pytest` command.
6. Issue the pull request.
